Learn R Programming

tweedie (version 2.2.1)

Tweedie internals: Tweedie internal function

Description

Internal tweedie functions.

Usage

dtweedie.dlogfdphi(y, mu, phi, power) dtweedie.logl(phi, y, mu, power) dtweedie.logl.saddle( phi, power, y, mu, eps=0) dtweedie.logv.bigp( y, phi, power) dtweedie.logw.smallp(y, phi, power) dtweedie.interp(grid, nx, np, xix.lo, xix.hi,p.lo, p.hi, power, xix) dtweedie.jw.smallp(y, phi, power ) dtweedie.kv.bigp(y, phi, power) dtweedie.series.bigp(power, y, mu, phi) dtweedie.series.smallp(power, y, mu, phi) stored.grids(power)

Arguments

y
the vector of responses
power
the value of $power$ such that the variance is $var(Y) = phi * mu^power$
mu
the mean
phi
the dispersion
grid
the interpolation grid necessary for the given value of $power$
nx
the number of interpolation points in the $xi$ dimension
np
the number of interpolation points in the $power$ dimension
xix.lo
the lower value of the transformed $xi$ value used in the interpolation grid. (Note that the value of $xi$ is from $0$ to $infty$, and is transformed such that it is on the range $0$ to $1$.)
xix.hi
the higher value of the transformed $xi$ value used in the interpolation grid.
p.lo
the lower value of $p$ value used in the interpolation grid.
p.hi
the higher value of $p$ value used in the interpolation grid.
xix
the value of the transformed $xi$ at which a value is sought.
eps
the offset in computing the variance function in the saddlepoint approximation. The default is eps=1/6 (as suggested by Nelder and Pregibon, 1987).

Details

These are not to be called by the user.

References

Nelder, J. A. and Pregibon, D. (1987). An extended quasi-likelihood function Biometrika, 74(2), 221--232.