dtweedie.saddle(y, xi=power, mu, phi, eps=1/6, power=NULL)eps=1/6
(as suggested by Nelder and Pregibon, 1987).mu,
phi
and
power.
power,
the distributions are still defined but cannot be written in closed form,
and hence evaluation is very difficult.
When $1 < power < 2$,
the distribution are continuous for $Y$ greater than zero,
with a positive mass at $Y=0$.
For $power > 2$,
the distributions are continuous for $Y$ greater than zero.This function approximates the density using the saddlepoint approximation defined by Nelder and Pregibon (1987).
dtweedie p <- 2.5
mu <- 1
phi <- 1
y <- seq(0, 10, length=100)
fy <- dtweedie( y=y, power=p, mu=mu, phi=phi)
plot(y, fy, type="l")
# Compare to the saddlepoint density
f.saddle <- dtweedie.saddle( y=y, power=p, mu=mu, phi=phi)
lines( y, f.saddle, col=2 )
Run the code above in your browser using DataLab