dtweedie_series: Series Evaluation for the Tweedie Probability Function

View source: R/dtweedie_series.R

dtweedie_seriesR Documentation

Series Evaluation for the Tweedie Probability Function

Description

Evaluates the probability density function (pdf) for Tweedie distributions using an infinite series, for given values of the dependent variable y, the mean mu, dispersion phi, and power parameter power. Not usually called by general users, but can be used in the case of evaluation problems.

Usage

dtweedie_series(y, power, mu,phi)

dtweedie.series(y, power, mu, phi)

Arguments

y

vector of quantiles.

power

scalar; the value of p such that the variance is \mbox{var}[Y]=\phi\mu^{p}.

mu

vector of mean \mu.

phi

vector of dispersion parameters \phi.

Value

A numeric vector of densities.

References

Dunn, Peter K and Smyth, Gordon K (2005). Series evaluation of Tweedie exponential dispersion model densities Statistics and Computing, 15(4). 267–280. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")}

Examples

# Plot a Tweedie density
y <- seq(0.01, 4, length = 50)
fy <- dtweedie_series(y, power = 1.1, mu = 1, phi = 1)
plot(y, fy, type = "l", lwd = 2, ylab = "Density")

tweedie documentation built on Feb. 7, 2026, 5:07 p.m.