logLiktweedie: Log-likelihood for Tweedie distributions

View source: R/logLiktweedie.R

logLiktweedieR Documentation

Log-likelihood for Tweedie distributions

Description

Evaluates the log-likelihood for a fitted Tweedie glm.

Usage

logLiktweedie(glm.obj, dispersion = NULL)

Arguments

glm.obj

a fitted glm object, fitted using the tweedie family.

dispersion

the dispersion parameter, usually extracted from glm.obj; however, occasionally a specified value of the dispersion may be needed.

Details

The log-Likelihood is computed by evaluating the density function.

Value

The value of the computed log-likelihood.

Note

Evaluating the likelihood can be time consuming, so the function may take some time for large data sets.

References

Dunn, P. K. and Smyth, G. K. (2008). Evaluation of Tweedie exponential dispersion model densities by Fourier inversion. Statistics and Computing, 18, 73–86. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-007-9039-6")}

Dunn, Peter K and Smyth, Gordon K (2005). Series evaluation of Tweedie exponential dispersion model densities Statistics and Computing, 15(4). 267–280. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")}

Jorgensen, B. (1997). Theory of Dispersion Models. Chapman and Hall, London.

Sakamoto, Y., Ishiguro, M., and Kitagawa G. (1986). Akaike Information Criterion Statistics. D. Reidel Publishing Company.

See Also

dtweedie

Examples

# Fit a Tweedie density using  tweedie  family function from  statmod
pretend <- data.frame( y = stats::rgamma(20, shape = 1, rate = 1) )
fit <- glm(y ~ 1, data = pretend, 
           family = statmod::tweedie(link.power = 0, var.power = 2.1))

# Compute the AIC
logLiktweedie(fit)


tweedie documentation built on Feb. 7, 2026, 5:07 p.m.