tweedie_lambda: The Probability of Observing a Zero Value for a Tweedie...

View source: R/tweedie_lambda.R

tweedie_lambdaR Documentation

The Probability of Observing a Zero Value for a Tweedie Density

Description

The probability that the variable takes the value of zero.

Usage

tweedie_lambda(mu, phi, power)

Arguments

mu

the mean parameter \mu.

phi

the dispersion parameter \phi.

power

the power parameter p (sometimes denoted \xi).

Value

The value of \lambda when 1 < p < 2 such that P(Y=0) = \exp(-\lambda). When p>2, a vector of zeros is returned.

References

Dunn, Peter K and Smyth, Gordon K (2005). Series evaluation of Tweedie exponential dispersion model densities Statistics and Computing, 15(4). 267–280. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")}

Examples

lambda <- tweedie_lambda(mu = 1:3, phi = 1, power = 1.1)
exp( -lambda)

# When p > 2, there is zero probability that Y = 0:
lambda  <- tweedie_lambda(mu = 1, phi = 1, power = 3.1)


tweedie documentation built on Feb. 7, 2026, 5:07 p.m.