tweedie_plot: Plot Tweedie Models

View source: R/tweedie_plot.R

tweedie_plotR Documentation

Plot Tweedie Models

Description

This function produced a plot of the specified Tweedie distribution.

Usage

tweedie_plot(y, xi = NULL, mu, phi, type = "pdf", power = NULL, add = FALSE, ...)

tweedie.plot(
  y,
  xi = NULL,
  mu,
  phi,
  type = "pdf",
  power = NULL,
  add = FALSE,
  ...
)

Arguments

y

the values for y in the plot.

xi

a synonym for power.

mu

the mean of the distribution \mu.

phi

the dispersion parameter \phi.

type

the type of plot, either PDF (the default) or CDF.

power

the variance power p.

add

logical; if TRUE, the plot is added to the current plot; if FALSE (the default) the plot is produced on a fresh plot.

...

plotting parameters passed to plot().

Details

If 1 < p < 2, the mass at Y=0 is automatically added.

Examples

y <- seq(0, 4, length = 50)
tweedie_plot(y, power = 1.1, mu = 1, phi = 1)



tweedie documentation built on Feb. 7, 2026, 5:07 p.m.