dtweedie_inversion: Fourier Inversion Evaluation for the Tweedie Probability Function
Description
Evaluates the probability density function (pdf) for Tweedie distributions using Fourier inversion,
for given values of the dependent variable y, the mean mu, dispersion phi, and power parameter power.
Not usually called by general users, but can be used in the case of evaluation problems.
A numeric vector of densities if details=FALSE; if details=TRUE, return a list with density (the density values), regions (the number of integration regions used) and methods (which of the three methods was used).
Arguments
y
vector of quantiles.
mu
the mean parameter \(\mu\).
phi
the dispersion parameter \(\phi\).
power
scalar; the power parameter \(p\).
method
the method to use; one of 1, 2, or 3 (the default).
verbose
logical; if TRUE, display some internal computation details. The default is FALSE.
details
logical; if TRUE, return a list with basic details of the integration. The default is FALSE.
IGexact
logical; if TRUE (the default), evaluate the inverse Gaussian distribution using the 'exact' values, otherwise uses inversion.
References
Dunn, P. K. and Smyth, G. K. (2008).
Evaluation of Tweedie exponential dispersion model densities by Fourier inversion.
Statistics and Computing,
18, 73--86.
tools:::Rd_expr_doi("10.1007/s11222-007-9039-6")
Dunn, P. K. and Smyth, G. K. (2008).
Evaluation of Tweedie exponential dispersion model densities by Fourier inversion.
Statistics and Computing,
18, 73--86.
tools:::Rd_expr_doi("10.1007/s11222-007-9039-6")