View source: R/dtweedie_saddle.R
| dtweedie_saddle | R Documentation |
Density function for the Tweedie EMDs using a saddlepoint approximation.
dtweedie_saddle(y, xi = NULL, mu, phi, eps = 1/6, power = NULL)
dtweedie.saddle(y, xi = NULL, mu, phi, eps = 1/6, power = NULL)
y |
vector of quantiles. |
xi |
scalar; the value of |
mu |
vector of mean |
phi |
vector of dispersion parameters |
eps |
the offset in computing the variance function; the default is |
power |
scalar; a synonym for |
A numeric vector of densities.
Dunn, P. K. and Smyth, G. K. (2008). Evaluation of Tweedie exponential dispersion model densities by Fourier inversion. Statistics and Computing, 18, 73–86. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-007-9039-6")}
Dunn, Peter K and Smyth, Gordon K (2005). Series evaluation of Tweedie exponential dispersion model densities Statistics and Computing, 15(4). 267–280. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")}
Nelder, J. A. and Pregibon, D. (1987). An extended quasi-likelihood function Biometrika, 74(2), 221–232. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/biomet/74.2.221")}
# Plot a Tweedie density
y <- seq(0.01, 4, length = 50)
fy <- dtweedie_saddle(y, power = 1.1, mu = 1, phi = 1)
plot(y, fy, type = "l", lwd = 2, ylab = "Density")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.