dtweedie_series: Series Evaluation for the Tweedie Probability Function
Description
Evaluates the probability density function (pdf) for Tweedie distributions using an infinite series,
for given values of the dependent variable y, the mean mu, dispersion phi, and power parameter power.
Not usually called by general users, but can be used in the case of evaluation problems.
Usage
dtweedie_series(y, power, mu,phi)
dtweedie.series(y, power, mu, phi)
Value
A numeric vector of densities.
Arguments
y
vector of quantiles.
power
scalar; the value of \(p\) such that the variance is \(\mbox{var}[Y]=\phi\mu^{p}\).
mu
vector of mean \(\mu\).
phi
vector of dispersion parameters \(\phi\).
References
Dunn, Peter K and Smyth, Gordon K (2005).
Series evaluation of Tweedie exponential dispersion model densities
Statistics and Computing,
15(4). 267--280.
tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")