View source: R/ptweedie_inversion.R
| ptweedie_inversion | R Documentation |
Evaluates the distribution function (df) for Tweedie distributions using Fourier inversion,
for given values of the dependent variable y,
the mean mu, dispersion phi, and power parameter power.
Not usually called by general users, but can be in the case of evaluation problems.
ptweedie_inversion(q, mu, phi, power, verbose = FALSE, details = FALSE, IGexact = TRUE)
ptweedie.inversion(q, power, mu, phi, verbose, details)
q |
vector of quantiles. |
mu |
the mean parameter. |
phi |
the dispersion parameter. |
power |
the power parameter |
verbose |
logical; if |
details |
logical; if |
IGexact |
logical; if |
If details = FALSE, a numeric vector of the distribution function values; if details = TRUE, a list containing CDF (a vector of the values of the distribution function) and regions (a vector of the number of integration regions used).
For special cases of p (i.e., p = 0, 1, 2, 3), where no inversion is needed, regions is set to NA for all values of q.
For special cases of q for other values of p (i.e., P(Y = 0)), regions is set to NA.
The 'exact' values for the inverse Gaussian distribution are not really exact, but evaluated using inverse normal distributions, for which very good numerical approximation are available in R.
Dunn, P. K. and Smyth, G. K. (2008). Evaluation of Tweedie exponential dispersion model densities by Fourier inversion. Statistics and Computing, 18, 73–86. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-007-9039-6")}
# Plot a Tweedie distribution function
y <- seq(0.01, 4, length = 50)
Fy <- ptweedie_inversion(y, mu = 1, phi = 1, power = 1.1)
plot(y, Fy, type = "l", lwd = 2, ylab = "Distribution function")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.