If details = FALSE, a numeric vector of the distribution function values; if details = TRUE, a list containing CDF (a vector of the values of the distribution function), regions (a vector of the number of integration regions used), and exitstatus (a vector, where a 1 for any value means a computational problem or target relative accuracy not reached, for the corresponding observation).
For special cases of \(p\) (i.e., \(p = 0, 1, 2, 3\)), where no inversion is needed, regions is set to NA for all values of q.
For special cases of q for other values of \(p\) (i.e., \(P(Y = 0)\)), regions is set to NA.