ptweedie_series: Series Evaluation for the Tweedie Distribution Function
Description
Evaluates the distribution function (df) for Tweedie distributions
with \(1 < p < 2\)
using an infinite series, for given values of the dependent variable y,
the mean mu, dispersion phi, and power parameter power.
Not usually called by general users, but can be in the case of evaluation problems.
logical; if TRUE, displays some internal computation details. The default is FALSE.
details
logical; if TRUE, returns the value of the distribution function and some details.
References
Dunn, Peter K and Smyth, Gordon K (2005).
Series evaluation of Tweedie exponential dispersion model densities
Statistics and Computing,
15(4). 267--280.
tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")