View source: R/tweedie_integrand.R
| tweedie_integrand | R Documentation |
Plots the integrand for Fourier inversion and the real and imaginary parts separately.
tweedie_integrand(y, power, mu, phi, t = seq(0, 5, length = 200),
type = "PDF", whichPlots = 1:4, yLimits = NULL)
y |
vector of quantiles. |
power |
a synonym for |
mu |
the mean parameter |
phi |
the dispersion parameter |
t |
the values of the variable over which to integrate; the default is |
type |
either |
whichPlots |
which combination of the four plots (described below) are produced; by default, all four are produced (i.e., |
yLimits |
the |
The Tweedie family of distributions belong to the class of exponential dispersion models (edms), famous for their role in generalized linear models.
The Tweedie distributions are the edms with a variance of the form \mbox{var}[Y] = \phi\mu^p where p is greater than or equal to one, or less than or equal to zero.
This function only evaluates for p greater than or equal to one.
Special cases include the normal (p = 0), Poisson (p = 1 with \phi = 1), gamma (p = 2) and inverse Gaussian (p = 3) distributions. For other values of power, the distributions are still defined but cannot be written in closed form, and hence evaluation is very difficult.
When 1 < p < 2, the distribution are continuous for Y greater than zero, with a positive mass at Y = 0. For p > 2, the distributions are continuous for Y greater than zero.
This function displays the integrand that is evaluated for computing the Fourier inversion, for the PDF or CDF.
A list containing the real and imaginary parts of k(t), Real and Imag respectively, plus the values of the integrand as IG.
The main purpose of the function is the side-effect of producing a 2\times2 grid of plots.
The first is the imaginary parts of k(t).
The second is \sin\Im k(t).
The third is the real part of \Re k(t)
The fourth is the integrand, with the envelope shown as a dashed line.
Peter Dunn (pdunn2@usc.edu.au)
Dunn, P. K. and Smyth, G. K. (2008). Evaluation of Tweedie exponential dispersion model densities by Fourier inversion. Statistics and Computing, 18, 73–86. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-007-9039-6")}
Dunn, Peter K and Smyth, Gordon K (2005). Series evaluation of Tweedie exponential dispersion model densities Statistics and Computing, 15(4). 267–280. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")}
Dunn, Peter K and Smyth, Gordon K (2001). Tweedie family densities: methods of evaluation. Proceedings of the 16th International Workshop on Statistical Modelling, Odense, Denmark, 2–6 July
Jorgensen, B. (1987). Exponential dispersion models. Journal of the Royal Statistical Society, B, 49, 127–162.
Jorgensen, B. (1997). Theory of Dispersion Models. Chapman and Hall, London.
Tweedie, M. C. K. (1984). An index which distinguishes between some important exponential families. Statistics: Applications and New Directions. Proceedings of the Indian Statistical Institute Golden Jubilee International Conference (Eds. J. K. Ghosh and J. Roy), pp. 579-604. Calcutta: Indian Statistical Institute.
dtweedie
tweedie_integrand(2, power = 3, mu = 1, phi = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.