View source: R/tweedie_lambda.R
| tweedie_lambda | R Documentation |
The probability that the variable takes the value of zero.
tweedie_lambda(mu, phi, power)
mu |
the mean parameter |
phi |
the dispersion parameter |
power |
the power parameter |
The value of \lambda when 1 < p < 2 such that P(Y=0) = \exp(-\lambda). When p>2, a vector of zeros is returned.
Dunn, Peter K and Smyth, Gordon K (2005). Series evaluation of Tweedie exponential dispersion model densities Statistics and Computing, 15(4). 267–280. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")}
lambda <- tweedie_lambda(mu = 1:3, phi = 1, power = 1.1)
exp( -lambda)
# When p > 2, there is zero probability that Y = 0:
lambda <- tweedie_lambda(mu = 1, phi = 1, power = 3.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.